# __Change Log__
>__LAST UPDATE:__ 23.02.2020  
>__STATUS:__ Pre-alpha  
>__VERSION:__ v0.0.1

___

## __Pre-alpha__
### __v0.0.1 (23.02.2022)__
- Project created.
- [Module](./z_console/module.py) class added.
___